/*global define */
define(['jquery', 'underscore', 'backbone'], 				
	function($, _, Backbone) {
	'use strict';

	// Registry Model 
	// ------------------
	var RegistryModel = Backbone.Model.extend({
		// This model contains additional fields needed for the Registry
		defaults: {
			// keyword options inserted into the Registry form for user to select from 	
			formOptions:
				{
					"workingGroup" : 
						["NCEAS 2165: Abrams: CompetitionTheory", 
						 "NCEAS 12308: Adair: ModelingLitterDecomposition", 
						 "NCEAS 9620: Adler: ClimateAndCoexistence", 
						 "NCEAS 10781: Aizen: PollinationAndReproduction", 
						 "NCEAS 9500: Allen: DiversityAndTemperature", 
						 "NCEAS 12061: Allen: UnifyingBiodiversityTheories", 
						 "NCEAS 2000: Allen: RestorationBiology", 
						 "NCEAS 12140: Allendorf: GeneticMonitoring", 
						 "NCEAS 12062: Allesina: ReverseEngineeringOfEcosystems", 
						 "NCEAS 2088: Alroy: FossilRecord", 
						 "NCEAS 3980: Alroy: PaleobiologyDatabase", 
						 "NCEAS 2149: Alroy: Postdoctoral Fellow", 
						 "NCEAS 12502: Altizer: MigrationDynamics", 
						 "NCEAS 3820: Altizer: HostBehavior", 
						 "NCEAS 6060: Altizer: HostBehaviorExtended", 
						 "NCEAS 2073: Amarasekare: Post-DoctoralFellow", 
						 "NCEAS 2002: Andelman: BiologicalDiversity", 
						 "NCEAS 2135: Andelman: BioDiversityExtended", 
						 "NCEAS 3960: Andelman: FSAssessments", 
						 "NCEAS 12690: Andelman: SNAP_AgricultureByDesign", 
						 "NCEAS 12665: Anderegg: TreeMortalityGroup", 
						 "NCEAS 12605: Anderson: GulfEcotoxicology", 
						 "NCEAS 2226: Arneberg: MammalianNematodes", 
						 "NCEAS 12592: Aronson: UrbanComparativeEcology", 
						 "NCEAS 4220: Ashley: MolecularData", 
						 "NCEAS 6460: Ashman: PollenLimitation ", 
						 "NCEAS 12064: Atkinson: Ecology'sMetabolicBasis", 
						 "NCEAS 12131: Aukema: Non-NativeForestInvasivesDGS", 
						 "NCEAS 12021: Aukema: TNC_EconomicsOfNon-nativeForestPests", 
						 "NCEAS 12031: Aukema: Non-NativeForestInvasivesWorkingGroup", 
						 "NCEAS 12130: Aukema: Non-NativeForestInvasivesSteering", 
						 "NCEAS 5980: Bakarr: GlobalGapAnalysis", 
						 "NCEAS 12141: Balch: WhatControlsFireFrequency?", 
						 "NCEAS 8940: Baron: COMPASS", 
						 "NCEAS 12685: Baruch-Mordo: SNAP_HydraulicFracturing", 
						 "NCEAS 2072: Bascompte: PostdoctoralFellow", 
						 "NCEAS 11201: Bascompte: ComplexEcosystems", 
						 "NCEAS 10981: Baskett: CoralBleaching", 
						 "NCEAS 12476: Baum: SharksOnCoralReefs", 
						 "NCEAS 2122: Beach: SystematicsCommunity", 
						 "NCEAS 4600: Becerra: LandscapeCoevolution", 
						 "NCEAS 2279: Beck: WetlandNurseries", 
						 "NCEAS 12678: Beck: SNAP_CoastalDefenses", 
						 "NCEAS 12292: Beechie: SalmonClimateResilience", 
						 "NCEAS 12481: Bever: SAB-2009-2010", 
						 "NCEAS 2146: Bjornstad: RecruitmentVariability", 
						 "NCEAS 2118: Bjornstad: StatisticalModels", 
						 "NCEAS 2179: Boersma: RecoveryPlansDGS", 
						 "NCEAS 12316: Bohannan: MicrobialTraitBiogeography", 
						 "NCEAS 5541: Bohannan: MicrobialBiodiversity", 
						 "NCEAS 8800: Bohannan: MicrobialBiodiversityExtended", 
						 "NCEAS 12575: Boone: EcologyOfEnvironmentalJustice", 
						 "NCEAS 6980: Borer: IntraguildPredation", 
						 "NCEAS 2275: Boring: EcosystemApplications", 
						 "NCEAS 12299: Bowman: PyrogeographyAndClimateChange", 
						 "NCEAS 12226: Bowman: WhatIsFire?", 
						 "NCEAS 2158: Bradshaw: NatureBoundary", 
						 "NCEAS 12663: Bridge: AnimalTrackingSoftware", 
						 "NCEAS 12587: Britton: PlantsForPlanting", 
						 "NCEAS 10682: Broitman: EBM_SocialDrivers", 
						 "NCEAS 10341: Brooks: GeochemistryAndInvertebrates", 
						 "NCEAS 4080: Brooks: MappingDistributions", 
						 "NCEAS 3560: Brown: Economics/DemographicModeling", 
						 "NCEAS 2460: Brown: Allometry", 
						 "NCEAS 2155: Brown: ESAPublications", 
						 "NCEAS 2268: Brown: SFI", 
						 "NCEAS 12145: Buckley: ReptileRangeDynamics", 
						 "NCEAS 12054: Buckley: SpeciesRangeDynamics", 
						 "NCEAS 12120: Budden: PublicationBiasInEcology", 
						 "NCEAS 12114: Bunting: Continental-ScalePaterrns", 
						 "NCEAS 2290: Burgman: ExtinctionRisk", 
						 "NCEAS 4860: Burgman: ConservationPriorities", 
						 "NCEAS 2090: Burton: ImmunologicalResponse ", 
						 "NCEAS 4820: Buston: HermaphroditeEcology", 
						 "NCEAS 12660: Byrnes: KelpAndClimateChange", 
						 "NCEAS 12541: Byrnes: BiodiversityAndTopology", 
						 "NCEAS 12055: Cadotte: PhylogenyAsAPredictorOfSpeciesCoexistence", 
						 "NCEAS 12503: Callaway: WetlandCarbonModeling", 
						 "NCEAS 3840: Callaway: AlpineElevationGradients", 
						 "NCEAS 2231: Cane: PollinatorDecline", 
						 "NCEAS 12551: Carbone: Semi-Arid/AridSoilRespiration", 
						 "NCEAS 12560: Cardinale: Diversity-FunctionSynthesis", 
						 "NCEAS 2038: Carpenter: SAB97", 
						 "NCEAS 2037: Carpenter: SAB1996", 
						 "NCEAS 2284: Carpenter: SynthesisSymposium", 
						 "NCEAS 2098: Carpenter: EcosystemPerturbation", 
						 "NCEAS 12024: Carroll: LandscapeAndPopulationConnectivity", 
						 "NCEAS 2148: Case: Endemism,Age,Area", 
						 "NCEAS 3040: Caswell: DemographySynthesis", 
						 "NCEAS 12584: Cavender-Bares: SustainabilityScienceSeminarDGS", 
						 "NCEAS 12069: Cavender-Bares: Ecophylogenetics", 
						 "NCEAS 2040: Chapin: ArcticBoreal", 
						 "NCEAS 2294: Chapin: FutureBiodiversity", 
						 "NCEAS 12437: Chase: GradientsofBetaDiversity", 
						 "NCEAS 9100: Chazdon: AgriculturalLandscapes", 
						 "NCEAS 11281: Christie: EBM_EBMFeasibility", 
						 "NCEAS 3440: Clark: NSF/EcologicalForecasting", 
						 "NCEAS 2293: Clark: TreeDispersal", 
						 "NCEAS 9520: Cleland: RoleOfFunctionalTraits", 
						 "NCEAS 12070: Cleland: FunctionalEcologySeminarDGS", 
						 "NCEAS 12147: Cleveland: TropicalNutrientLimitation", 
						 "NCEAS 6500: Cole: AquaticCarbonFluxes", 
						 "NCEAS 2183: Coleman: EPRI", 
						 "NCEAS 12475: Comita: SpeciesAbundance", 
						 "NCEAS 9762: Condit: NeotropicalTreeDistributions", 
						 "NCEAS 12479: Condon: GlobalJellyfishBlooms", 
						 "NCEAS 4660: Connors: KidsDoEcology", 
						 "NCEAS 12574: Cook: PhenologyAndClimate", 
						 "NCEAS 2250: Cornell: Pred-Path3", 
						 "NCEAS 12208: Cornell: NicheConservatism", 
						 "NCEAS 12259: Costanza: IntegratedHistory", 
						 "NCEAS 2286: Costanza: NaturalCapitalWS", 
						 "NCEAS 2058: Costanza: NaturalCapital", 
						 "NCEAS 12381: Costello: Limited-InformationFisheriesManagement", 
						 "NCEAS 12129: Costello: NearshoreFinfish", 
						 "NCEAS 12136: Costello: PropertyRightsAndFisheries", 
						 "NCEAS 6240: Cottenie: LocalvsRegional", 
						 "NCEAS 2100: Cottingham: EcosystemStateChanges", 
						 "NCEAS 2221: Courtney: HCPReport", 
						 "NCEAS 2050: Courtney: SEI", 
						 "NCEAS 3061: Covich: DroughtEffects", 
						 "NCEAS 12320: Crone: TestingMatrixModels", 
						 "NCEAS 12321: Crowder: SustainableGlobalSeafoodMarket", 
						 "NCEAS 7140: Crowder: MarineConservationPolicy", 
						 "NCEAS 2101: Crowley: VisitingScientist", 
						 "NCEAS 8600: Cuddington: ModelingEcosystemEngineers", 
						 "NCEAS 5060: Cunningham: NAtlanticProject", 
						 "NCEAS 2151: Dadd: Species2000", 
						 "NCEAS 10761: Damschen: PatchinessInKelpForests", 
						 "NCEAS 2041: Damuth: MammalCommunity", 
						 "NCEAS 10421: Davidson: SpatialStoichiometry", 
						 "NCEAS 10901: Davies: CoexistenceAndCompetition", 
						 "NCEAS 4040: Davis: CLP", 
						 "NCEAS 7740: Davis: CoastalReserves", 
						 "NCEAS 2175: Davis: NCCPMonitoring", 
						 "NCEAS 12645: Davis: MarineDebris", 
						 "NCEAS 2096: Debenham: CenterAssociate", 
						 "NCEAS 11923: DeClerck: AgrobiodiversityAndServiceDGS", 
						 "NCEAS 12691: DeClerck: SNAP_EcosystemAndResilienceMetrics", 
						 "NCEAS 12368: de Roos: DevelopmentalEcology ", 
						 "NCEAS 2095: de Roos: Project2095", 
						 "NCEAS 3080: de Valpine: InsectPopulation", 
						 "NCEAS 10281: Doak: EBM_PredatorEffectiveness", 
						 "NCEAS 2198: Dobson: DiseasesAndConservation", 
						 "NCEAS 12667: Dobson: LandUseChangeAndInfectiousDisease", 
						 "NCEAS 4221: Donoghue: CommunityEcology", 
						 "NCEAS 10921: Drake: EcologicalMachineLearning", 
						 "NCEAS 7961: Drake: DiseaseRiskAnalysis", 
						 "NCEAS 12595: Edmunds: ReefsOfTheFuture", 
						 "NCEAS 2224: Eldredge: EcologicalProcesses", 
						 "NCEAS 2029: Ellison: ESAMeeting", 
						 "NCEAS 2105: Ellner: Project2105", 
						 "NCEAS 2154: Elser: EcologicalStoichiometry", 
						 "NCEAS 7560: Enquist: AllometryMechanism", 
						 "NCEAS 12290: Enquist: BotanicalInformationAndEcologyNetworkBIEN", 
						 "NCEAS 12254: Fagan: DendriticLandscapes", 
						 "NCEAS 2053: Fagan: HabitatEdges", 
						 "NCEAS 8060: Farber: LTEREcosystemServices", 
						 "NCEAS 2208: Field: CarbonBalance", 
						 "NCEAS 9781: Field: CarbonVulnerability", 
						 "NCEAS 3101: Flannigan: LandscapeFires", 
						 "NCEAS 12112: Fleishman: ConnectivityinNevada", 
						 "NCEAS 12118: Fleishman: WCS_ClimateChangeAndConservation", 
						 "NCEAS 12634: Fleishman: EcologicalThresholds ", 
						 "NCEAS 12192: Fleishman: PelagicSystemDynamics", 
						 "NCEAS 12122: Fleishman: PelagicOrganismDeclines", 
						 "NCEAS 12379: Fleishman: OceanEstuaryInteractions", 
						 "NCEAS 12198: Fleishman: PelagicFishesContaminants", 
						 "NCEAS 12294: Fleishman: SalmonClimateChange", 
						 "NCEAS 12304: Fleishman: ClimateChangeAndForestPathogens", 
						 "NCEAS 12135: Fleishman: SustainableFisheriesSteering", 
						 "NCEAS 12133: Fleishman: SalmonSteering", 
						 "NCEAS 12194: Fleishman: MarineValuationWorkshop", 
						 "NCEAS 12134: Fleishman: WildSalmonEcosystems", 
						 "NCEAS 6981: Floeter: AtlanticReefFishes", 
						 "NCEAS 4160: Francis: MarineManagement1", 
						 "NCEAS 3360: Franklin: BiologicalLegacy", 
						 "NCEAS 2540: Gabriel: InducibleDefenses", 
						 "NCEAS 12023: Gaines: SustainableFisheriesManagement", 
						 "NCEAS 6340: Gamon: SpecNet", 
						 "NCEAS 12680: Gates: Earth Cube", 
						 "NCEAS 12478: Gates: CoralResilienceMechanisms", 
						 "NCEAS 12659: Gerber: MarineMammalManagementModels", 
						 "NCEAS 4020: Gerber: OtterModeling", 
						 "NCEAS 12457: Gerber: VertebrateConservation", 
						 "NCEAS 2102: Gerber: EffectsofDisease", 
						 "NCEAS 3102: Gergel: ArrangementandRunoff", 
						 "NCEAS 2281: Gerrard: Project2281", 
						 "NCEAS 2254: Gilpin: ConservationStrategies", 
						 "NCEAS 2077: Gilpin: ConservationStrategiesEXT", 
						 "NCEAS 12692: Girvetz: SNAP_SmartAgPlanning", 
						 "NCEAS 2150: Gittleman: PhylogenyAndConservation", 
						 "NCEAS 5940: Godfray: SAB02-03", 
						 "NCEAS 12689: Goldstein: SNAP_UrbanWaterSecurity", 
						 "NCEAS 6040: Gonzalez Guzman: GonzalezVisit", 
						 "NCEAS 2500: Goodchild: GDLMeeting", 
						 "NCEAS 8840: Goodin: LTERClimateCommittee", 
						 "NCEAS 10941: Gotelli: ModelingSpeciesDiversity", 
						 "NCEAS 12679: Goulding: SNAP_WesternAmazonia", 
						 "NCEAS 2018: Gower: ProductivityDecline", 
						 "NCEAS 11341: Granek: EBM_ManagingInterfaceHabitats", 
						 "NCEAS 3620: Greene: ContinentalShelfEcosystems", 
						 "NCEAS 2153: Grimm: ATBGC", 
						 "NCEAS 2440: Grimm: SAB1999-2000", 
						 "NCEAS 2920: Grimm: Sabbatical(ATBGC)", 
						 "NCEAS 5601: Gross: GrasslandDiversity", 
						 "NCEAS 12558: Gross: ClonalPlantsAndFertilization", 
						 "NCEAS 3580: Groves: Sabbatical", 
						 "NCEAS 2121: Groves: NatureConservancy", 
						 "NCEAS 12464: Guerry: EBM_CulturalEcosystemServices", 
						 "NCEAS 2120: Gunderson: SustainableFutures", 
						 "NCEAS 2106: Gyllenberg: MetaModels", 
						 "NCEAS 12295: Hacker: SAB: 2008-2009", 
						 "NCEAS 2225: Hackett: ScientificCollaboration", 
						 "NCEAS 8080: Hackett: EcologyTransformed", 
						 "NCEAS 7600: Halpern: PredictingCommunityLevelResponses", 
						 "NCEAS 9400: Halpern: MappingMarineWilderness", 
						 "NCEAS 12108: Halpern: HumanImpactsInTheCaliforniaCurrent", 
						 "NCEAS 12110: Hampton: KDE Poster Day", 
						 "NCEAS 12298: Hampton: DesigningLargeScaleManagement", 
						 "NCEAS 12675: Hampton: NCEASSummerInstitute", 
						 "NCEAS 5240: Hannah: AndesConservation", 
						 "NCEAS 2107: Hanski: SabbaticalFellow", 
						 "NCEAS 8100: Harlan: UrbanEcology", 
						 "NCEAS 6840: Harmon: DecompositionSynthesis", 
						 "NCEAS 2308: Hart: WesternForests", 
						 "NCEAS 2600: Harvell: OceanDiseases", 
						 "NCEAS 7280: Harvell: OceanDiseasesExtended", 
						 "NCEAS 5020: Hastings: DesignReserves", 
						 "NCEAS 3460: Hawkins: Energy-diversityRelationships", 
						 "NCEAS 12668: He: BiodiversityInNeighborhood", 
						 "NCEAS 2295: Helly: Project2295", 
						 "NCEAS 7520: Hibbard: EMDI IV", 
						 "NCEAS 2042: Hibbard: EMDI", 
						 "NCEAS 4400: Hibbard: EMDI II", 
						 "NCEAS 5300: Hibbard: EMDI III", 
						 "NCEAS 12307: Hilborn: MarineManagementDGS", 
						 "NCEAS 2025: Hilborn: PredictingExtinction", 
						 "NCEAS 10961: Hochberg: LifeHistoryOfGroups", 
						 "NCEAS 7760: Hochberg: HumanCulturalDiversity", 
						 "NCEAS 6640: Hochberg: HumanSocialBehavior", 
						 "NCEAS 12482: Hoeksema: MycorrhizalSymbiosisNetworkDGS", 
						 "NCEAS 11882: Hoeksema: MycorrhizalManagementExtended", 
						 "NCEAS 8561: Hoeksema: MycorrhizalManagement", 
						 "NCEAS 2620: Holl: LandscapeRestoration", 
						 "NCEAS 2309: Holt: SpeciesBorders", 
						 "NCEAS 2108: Holyoak: Project2108", 
						 "NCEAS 2039: Hosseini: Project2039", 
						 "NCEAS 7940: Houlahan: SpatialTemporalCommunityDynamics", 
						 "NCEAS 2064: Howarth: NitrogenTransport", 
						 "NCEAS 5200: Huenneke: DiversityReduction", 
						 "NCEAS 2260: Hunsaker: SpatialUncertainty", 
						 "NCEAS 9300: Hurlbert: StructureOfGeographicRanges", 
						 "NCEAS 2244: Ives: CommunityDynamics", 
						 "NCEAS 2214: Jackson: MarineRecords", 
						 "NCEAS 2178: Jackson: RootModels", 
						 "NCEAS 3540: Jennings: GraduateStudentIntern", 
						 "NCEAS 12389: Johnson: SelectionAndPopulationDynamics", 
						 "NCEAS 2161: Johnson: ForestFires", 
						 "NCEAS 12662: Jones: CheatingInMutualisms", 
						 "NCEAS 2059: Jones: DataManagement", 
						 "NCEAS 12671: Jones: ISEES", 
						 "NCEAS 12193: Jones: DataManagementSANParks", 
						 "NCEAS 12519: Jones: DataONE", 
						 "NCEAS 12126: Jones: FIRST_II", 
						 "NCEAS 12370: Jones: VirtualDataCenter(VDC)", 
						 "NCEAS 6000: Jones: NSFNeonInfomatics", 
						 "NCEAS 6680: Jones: SEEK", 
						 "NCEAS 12206: Jones: KeplerCOREDevelopment", 
						 "NCEAS 12472: Jones: SemanticEnhancements", 
						 "NCEAS 10581: Juanes: PomatomusSaltatrix", 
						 "NCEAS 2621: Juanes: Predator-preyAllometry", 
						 "NCEAS 2143: Kaandorp: SessileGrowth", 
						 "NCEAS 12670: Kappel: OceanTippingPointsFormallyEcosystemThresholds", 
						 "NCEAS 8200: Kareiva: EcosystemServicesAndBiodiversity", 
						 "NCEAS 2171: Kareiva: UrbanModeling", 
						 "NCEAS 2049: Kareiva: HabitatConservation", 
						 "NCEAS 2015: Kareiva: Project2015", 
						 "NCEAS 2084: Kaufman: DiversityGradient", 
						 "NCEAS 5900: Keitt: KeittVisit", 
						 "NCEAS 2820: Kelly: MastingDynamics", 
						 "NCEAS 2784: Kerr: CarbonSequestrationII", 
						 "NCEAS 11601: King: InferenceForMechanisticModels", 
						 "NCEAS 6140: Kinnaird: ForestHornbills", 
						 "NCEAS 2169: Kinzig: BiodiversityandEcosystems", 
						 "NCEAS 2010: Kitchell: ApexPredators", 
						 "NCEAS 6220: Kitchell: FoodWebModels", 
						 "NCEAS 2109: Klaas: Project2109", 
						 "NCEAS 4460: Kolstad: BiodiversityEconomics", 
						 "NCEAS 12374: Konrad: FlowExperiments", 
						 "NCEAS 10584: Koricheva: Meta-analysisInEcology", 
						 "NCEAS 9381: Kremen: RestoringPollinationServices", 
						 "NCEAS 9080: Krivan: AdaptivePopulationDynamics", 
						 "NCEAS 5220: Kunz: BatProject", 
						 "NCEAS 12106: Lafferty: ParasitesAndFoodWebs", 
						 "NCEAS 12333: Lancaster: DiversificationRates", 
						 "NCEAS 5081: Langford: EvaluationFunctions", 
						 "NCEAS 7901: Larson: EcologicalMetaphors", 
						 "NCEAS 11061: Leavitt: LakeVariability", 
						 "NCEAS 3920: Leibold: Metacommunities", 
						 "NCEAS 2126: Lewinsohn: Insect-PlantAssemblages", 
						 "NCEAS 2305: Liebhold: SabbaticalVisit", 
						 "NCEAS 12378: Liebhold: EradicatingInvasiveInsects", 
						 "NCEAS 2162: Liebhold: SpatialAnalysis", 
						 "NCEAS 12081: Lockwood: Rarity_And_Extinction", 
						 "NCEAS 8140: Lodge: InvasiveSpecies", 
						 "NCEAS 4800: Loik: PrecipNetSynthesis ", 
						 "NCEAS 2660: Lomolino: FutureBiogeography", 
						 "NCEAS 9241: Lortie: ProgressAndPublicationBias", 
						 "NCEAS 12651: Lortie: OpenPublishingForEcology", 
						 "NCEAS 4263: Losos: AdaptiveRadiation", 
						 "NCEAS 9861: Lovvorn: PhysiologyAndTrophicCoupling", 
						 "NCEAS 2080: Lubchenco: MarineReserves", 
						 "NCEAS 3880: Luo: NitrogenAndCO2", 
						 "NCEAS 3743: Lyons: CommunityStructure", 
						 "NCEAS 12428: Mack: FireSeverityInTheFarNorth", 
						 "NCEAS 12300: Madrinan: HabitatSalmonClimate", 
						 "NCEAS 12293: Mantua: SalmonRangeLimitations", 
						 "NCEAS 11063: Marquet: PowerLawsInEcology", 
						 "NCEAS 11081: Marsh: PopulationMonitoring", 
						 "NCEAS 12658: Marsh: ToadsRoadsNodesDGS", 
						 "NCEAS 12001: Martinez: NetworkEcoinformatics", 
						 "NCEAS 12602: Maunder: NonlinearModelingTools", 
						 "NCEAS 2093: Maurer: GeographicPopulation", 
						 "NCEAS 3300: Mazer: NeotropicalRainforest", 
						 "NCEAS 7680: McCain: ElevationalTrends", 
						 "NCEAS 12609: McCauley: EBM_OfCoastalMarineSystems", 
						 "NCEAS 3741: McCullough: InvasionPathways", 
						 "NCEAS 12455: McDonald: UrbanizationAndEcosystems", 
						 "NCEAS 12504: McGill: EnvironmentAndOrganisms", 
						 "NCEAS 11121: McGill: UnderstandingSADs", 
						 "NCEAS 12470: McLeod: EBM_AssessingMarineEcosystemHealth", 
						 "NCEAS 9961: McRae: LandscapeGenetics", 
						 "NCEAS 9280: Melian: DynamicBehaviorInEcologicalNetworks", 
						 "NCEAS 12306: Melian: UnifyingNiche-neutralTheories", 
						 "NCEAS 12276: Menge: EcosystemDevelopment", 
						 "NCEAS 2188: Merrick: NCEDRGSR", 
						 "NCEAS 10681: Micheli: EBM_ScienceFrameworksForEBM", 
						 "NCEAS 2234: Micheli: MarineCommunities", 
						 "NCEAS 2091: Michener: ManagedFloods", 
						 "NCEAS 4720: Michener: PBI", 
						 "NCEAS 2204: Milne: LandscapeEcology", 
						 "NCEAS 8020: Mitchell: BioticInteractionsAndInvasions", 
						 "NCEAS 12573: Mittelbach: CommunityEcologyInTransition", 
						 "NCEAS 5580: Mittelbach: DiversityDeterminants", 
						 "NCEAS 9963: Mittelbach: BiodiversityAndSpeciation", 
						 "NCEAS 6660: Moe: StoichiometryPopulation", 
						 "NCEAS 4480: Moehlman: CanidEcology", 
						 "NCEAS 7000: Moles: SeedMassEvolution", 
						 "NCEAS 2227: Mooney: EcologicalMonitoring", 
						 "NCEAS 3221: Moore: DetritusDynamics", 
						 "NCEAS 12567: Moritz: GlobalFireEcology", 
						 "NCEAS 8141: Morris: StochasticDemography", 
						 "NCEAS 2212: Moss: AmboseliResearch", 
						 "NCEAS 12460: Mourad: TeachingWithLargeDatasetsDGS", 
						 "NCEAS 4300: Muller-Landau: TreeStrategy", 
						 "NCEAS 2264: Murdoch: CPDV", 
						 "NCEAS 2142: Murdoch: EAC", 
						 "NCEAS 2271: Murdoch: PopulationDynamics", 
						 "NCEAS 9982: Murdoch: InternationalConservation", 
						 "NCEAS 2035: Murdoch: SAB95", 
						 "NCEAS 2289: Murdoch: Spatio-Temporal", 
						 "NCEAS 3900: Murray: MicrobialCooperation", 
						 "NCEAS 2190: Naiman: HydrologicalRegimes", 
						 "NCEAS 4440: Naiman: RiparianEcology", 
						 "NCEAS 2065: Nisbet: ToxicantsEffects", 
						 "NCEAS 12253: Norby: FACE-ModelInteraction", 
						 "NCEAS 12438: Oberbauer: PhenologicalChangeInTundraPlants", 
						 "NCEAS 7880: O'Brien: ArcticLakeModeling", 
						 "NCEAS 12347: O'Connor: EcologyTemperatureScaling", 
						 "NCEAS 12664: O'Connor: WarmingFoodWebs", 
						 "NCEAS 12125: O'Halloran: AnalysisOfEcosystemProcesses ", 
						 "NCEAS 2267: Ojima: TraceGas", 
						 "NCEAS 2071: Olson: FishingStrategies", 
						 "NCEAS 8980: Orrock: MammalianHerbivores", 
						 "NCEAS 10002: Orth: GlobalSeagrassTrajectories", 
						 "NCEAS 2240: Osenberg: Meta-Analysis4", 
						 "NCEAS 9340: Osherenko: OceanEcosystemManagement", 
						 "NCEAS 2076: Ostfeld: InfectiousDisease", 
						 "NCEAS 4100: Owen-Smith: HerbivoreDynamics", 
						 "NCEAS 2278: Pace: EcosystemProgress", 
						 "NCEAS 3420: Pace: SAB00-01", 
						 "NCEAS 4180: Packer: SerengetiEcosystem", 
						 "NCEAS 7362: Packer: SerengetiEcosystemExtended", 
						 "NCEAS 9382: Padilla: InvadersAndMarineReserves", 
						 "NCEAS 4700: Palmer: StreamRestoration", 
						 "NCEAS 6740: Palmer: ESAEcologicalVisionsCommittee", 
						 "NCEAS 6900: Palmer: SAB2003-2004", 
						 "NCEAS 2117: Parker: InvasionBiology", 
						 "NCEAS 12647: Parker: AdvancingSynthesis", 
						 "NCEAS 12178: Parker: DisciplinarySynthesis", 
						 "NCEAS 2381: Parmenter: BONWorkshop", 
						 "NCEAS 2238: Parmesan: GlobalChange", 
						 "NCEAS 6920: Parrish: MarineConservationTextbook", 
						 "NCEAS 2062: Parton: Tree-GrassInteractions", 
						 "NCEAS 6881: Pascual: SeasonalityOfInfectiousDiseases", 
						 "NCEAS 12477: Pau: HawaiianC3-C4Grasses", 
						 "NCEAS 12179: Pavia: MPAsInOceanEBM_DGS", 
						 "NCEAS 2180: Peet: VegetationClassification", 
						 "NCEAS 4340: Peet: VegetationDatabase", 
						 "NCEAS 12203: Peterman: SalmonClimateMonitoring", 
						 "NCEAS 12296: Petersen: SalmonSpeciesSensitivit", 
						 "NCEAS 4980: Peterson: PredictingDistributions", 
						 "NCEAS 2086: Peterson: SAB98", 
						 "NCEAS 2184: Peterson: SAB1999", 
						 "NCEAS 12637: Peterson: SpatialStatsForStreams", 
						 "NCEAS 2700: Peterson: EcologicalOrganization", 
						 "NCEAS 2128: Pfaff: CarbonSequestration", 
						 "NCEAS 2032: Porter: Project2032", 
						 "NCEAS 4500: Porter: LandscapePhysiology", 
						 "NCEAS 2129: Possingham: DecisionTheory", 
						 "NCEAS 12686: Possingham: SNAP_RidgesToReefsFisheries", 
						 "NCEAS 12463: Possingham: EBM_ConservationDecisionMakingInTheCoralTriangleInitiative", 
						 "NCEAS 3240: Post: EcosystemStability", 
						 "NCEAS 9140: Preisser: DoesFearMatter", 
						 "NCEAS 6760: Pressey: PlanningTools", 
						 "NCEAS 2009: Pressey: SitingReserves", 
						 "NCEAS 2017: Prince: WorldwideNPP", 
						 "NCEAS 5920: Pyke: PykeNature", 
						 "NCEAS 12349: Queenborough: PlantBreedingSystems", 
						 "NCEAS 2185: Quinn: IABINWorkshop", 
						 "NCEAS 2304: Ralls: FarmlandStrategies", 
						 "NCEAS 12182: Randerson: TerrestrialEcosystemsAndClimatePolicy", 
						 "NCEAS 12197: Ranganathan: ConservationPlanningInArgentina", 
						 "NCEAS 11481: Rathcke: SAB2006-2008", 
						 "NCEAS 9580: Real: NARabiesDatabase", 
						 "NCEAS 2199: Real: DiseaseDynamics", 
						 "NCEAS 11103: Regan: EnvironmentalDecisionMaking", 
						 "NCEAS 2840: Reichman: KDI/KNB", 
						 "NCEAS 2044: Reichman: DataMeeting", 
						 "NCEAS 2046: Reichman: EACMeeting", 
						 "NCEAS 2841: Reichman: MarineData", 
						 "NCEAS 2229: Reichman: KDIMeeting", 
						 "NCEAS 8960: Reichman: EcosystemBasedManagement", 
						 "NCEAS 2880: Reichman: LosMarineros1", 
						 "NCEAS 2187: Reichman: NSFBON", 
						 "NCEAS 2219: Reiners: EcologicalInfluences", 
						 "NCEAS 2031: Reiners: EcoInfluence", 
						 "NCEAS 2296: Rex: DeepSeaBiodiversity", 
						 "NCEAS 12449: Richardson: MarineClimateImpacts", 
						 "NCEAS 12608: Ricketts: SAB-2010-2011", 
						 "NCEAS 9881: Ritchie: TrophicThermodynamics", 
						 "NCEAS 3242: Roberts: NewVegetationEcology", 
						 "NCEAS 2720: Robles: BenthicPopulations", 
						 "NCEAS 12474: Rodriguez: ParasitoidDiversity", 
						 "NCEAS 12352: Rosenberg: ModernLandscapeGenetics", 
						 "NCEAS 2400: Rothstein: CowbirdManagement", 
						 "NCEAS 2147: Roughgarden: EcologicalEconomics", 
						 "NCEAS 2292: Roughgarden: EcologyandEconomics", 
						 "NCEAS 8920: Ruckelshaus: SAB2004-2006", 
						 "NCEAS 2262: Russell: PopulationAnalysis", 
						 "NCEAS 2066: Russell: SamplingCurves", 
						 "NCEAS 2068: Rustad: EcosystemWarming", 
						 "NCEAS 12240: Ryan: ZoonoticModelsAndLandscapes", 
						 "NCEAS 12354: Sabo: DamsAndBiogeography", 
						 "NCEAS 12444: Sabo: HumanImpactsOnFreshwaterSustainability", 
						 "NCEAS 12656: Sabo: SAB-2012", 
						 "NCEAS 3780: Sabo: LandscapeScale", 
						 "NCEAS 9380: Sagarin: DarwinianHomelandSecurity", 
						 "NCEAS 8041: Sax: InsightsFromExotics", 
						 "NCEAS 12377: Schildhauer: EcoinfoGSR", 
						 "NCEAS 12440: Schildhauer: SONet", 
						 "NCEAS 12128: Schildhauer: ObservationWorkshop", 
						 "NCEAS 7981: Schimel: MicrobesAndEcosystems", 
						 "NCEAS 12467: Schlenk: UrbanRunoff", 
						 "NCEAS 2152: Schmitz: IndividualScale", 
						 "NCEAS 8541: Schnitzer: LianaEcology", 
						 "NCEAS 2166: Schultz: Area Management", 
						 "NCEAS 11961: Schulz: QualityEffectsEfficiency", 
						 "NCEAS 12356: Schuur: PermafrostAndRadiocarbon", 
						 "NCEAS 2094: Seabloom: Post-Doc", 
						 "NCEAS 2276: Seastedt: AERCMeeting", 
						 "NCEAS 10741: Selkoe: MarineDispersal", 
						 "NCEAS 2174: Semmens: Project2174", 
						 "NCEAS 2087: Semmens: LosMarineros", 
						 "NCEAS 8340: Shachak: LandscapeModulators", 
						 "NCEAS 11561: Shaw: GlobalClimateChange", 
						 "NCEAS 2297: Shea: PopulationManagement", 
						 "NCEAS 12666: Shevtsov: EcologicalEnergetics", 
						 "NCEAS 2092: Shimada: Project2092", 
						 "NCEAS 10022: Shurin: TrophicStructureComparisons", 
						 "NCEAS 11981: Shurin: TrophicStructureComparisonsExtended", 
						 "NCEAS 3260: Shurin: DetectingInteractions", 
						 "NCEAS 12204: Sibert: ADMB", 
						 "NCEAS 2054: Siegel: JGOFS", 
						 "NCEAS 2013: Sih: EcologicalConcepts", 
						 "NCEAS 3640: Silander: BayesianMacro-ecology", 
						 "NCEAS 2182: Smith: BodySize", 
						 "NCEAS 10041: Smith: Phase-shiftsOnCoralReefs", 
						 "NCEAS 2034: Smith: Project2034", 
						 "NCEAS 2005: Sork: MetapopulationModels", 
						 "NCEAS 2057: Sork: GeneFlow", 
						 "NCEAS 12622: Sorte: ClimateAndInvasions", 
						 "NCEAS 2140: Stanford: OBFSInformatics", 
						 "NCEAS 2259: Steffen: GCTE", 
						 "NCEAS 10081: Stephens: TimeAndSpeciesRichness", 
						 "NCEAS 5660: Stevens: EnvironmentalDeterminants", 
						 "NCEAS 3500: Stine: DecisionSupportTool", 
						 "NCEAS 10101: Stockwell: NicheModelingBook", 
						 "NCEAS 11003: Strier: PrimateLifeHistories ", 
						 "NCEAS 2760: Stromberg: CaliforniaGrasslands", 
						 "NCEAS 2011: Strong: Deep-SeaBiodiversity", 
						 "NCEAS 12094: Swaddle: DiversityAndWNV", 
						 "NCEAS 2172: Taper: EvidenceProject", 
						 "NCEAS 8581: Templer: Nitrogen15TracerSynthesis", 
						 "NCEAS 12582: Tewksbury: NaturalHistory", 
						 "NCEAS 2030: Thompson: CoevolutionWorkshop", 
						 "NCEAS 2220: Tilman: EcologicalForecasting", 
						 "NCEAS 2287: Tilman: SpatialEcology", 
						 "NCEAS 3400: Tilman: BiodiversityComposition", 
						 "NCEAS 2115: Tilman: Project2115", 
						 "NCEAS 7040: Torchin: BiologicalInvasions", 
						 "NCEAS 4680: Travis: SAB01-02", 
						 "NCEAS 12289: Turner: TradeAndForestInvasives", 
						 "NCEAS 2291: Turner: Project2291", 
						 "NCEAS 12669: Urban: EcosystemServices", 
						 "NCEAS 10626: Urban: EvolvingMetacommunities", 
						 "NCEAS 10641: Urban: TraitsInSpace", 
						 "NCEAS 5600: Vazquez: NullModels", 
						 "NCEAS 8321: Vellend: MetapopulationDynamics", 
						 "NCEAS 4540: Venable: DesertAnnuals", 
						 "NCEAS 8522: Verburg: LakeEnergyFluxes", 
						 "NCEAS 12097: Vieglais: SemanticWebForEcology", 
						 "NCEAS 3340: Vorosmarty: ArcticHydrology", 
						 "NCEAS 12661: Voyles: DiseaseInducedExtinction", 
						 "NCEAS 2008: Wagner: Climatologists'Meeting", 
						 "NCEAS 12358: Wagner: LandscapeGeneticsDGS", 
						 "NCEAS 2067: Waide: LTERNetwork", 
						 "NCEAS 2258: Walker: TundraResponse", 
						 "NCEAS 12164: Walsh: EfficientWildlifeVaccination", 
						 "NCEAS 12559: Waples: RedFlagsAndExtinctionRisk", 
						 "NCEAS 2283: Warner: MarinePopulations", 
						 "NCEAS 12100: Weiner: PlantReproductiveAllometry", 
						 "NCEAS 5261: White: NSFBiocomplexity", 
						 "NCEAS 3281: Wiens: LandscapeSynthesis", 
						 "NCEAS 11704: Wilcox: Market-basedMarineConservation", 
						 "NCEAS 2110: Wilkinson: CRCCPlanning", 
						 "NCEAS 12360: Williams: EvolutionaryDemography", 
						 "NCEAS 2201: Williams: QuaternaryEcosystems", 
						 "NCEAS 2085: Willig: LatitudinalGradient", 
						 "NCEAS 12687: Wilson: SNAP_DataLimitedFisheries", 
						 "NCEAS 2197: Wilson: EnvironmentandDisease", 
						 "NCEAS 4760: Wilson: OrganismalInteractions", 
						 "NCEAS 2104: Wilson: Project2104", 
						 "NCEAS 12380: Wolkovich: PlanktonCommunitiesAndClimateChange", 
						 "NCEAS 12218: Woods: Long-TermForestData", 
						 "NCEAS 12109: Worm: MarineManagement", 
						 "NCEAS 6860: Worm: MarineBiodiversityEcosystemFunction", 
						 "NCEAS 10645: Zhuang: SynthesizingCH4Emissions", 
						 "NCEAS 10241: Zilov: LakeBaikalPlankton"]
				}
			
		}
		
	});
	return RegistryModel;
});
